@@ -18,6 +18,7 @@ from .cli_base import (
     arg_filters,
     arg_out,
     arg_against,
+    arg_all,
     get_repo_context,
 )
 from .report_struct import Report
@@ -25,6 +26,7 @@ from .constants import HOME_ENV_PATH, GITHUB_MD_REPORT_FILE_NAME
 from .bootstrap import bootstrap
 from .utils import no_subcommand, extract_gh_owner_repo, remove_html_comments
 from .gh_api import resolve_gh_token
+from .project_config import ProjectConfig
 
 # Import fix command to register it
 from .commands import fix, gh_react_to_comment, repl, deploy, version  # noqa
@@ -88,6 +90,23 @@ def cli(
         bootstrap(verbosity)
 
 
+def _consider_arg_all(all: bool, refs: str, merge_base: bool) -> tuple[str, bool]:
+    """
+    Handle the --all option logic for commands.
+    Returns:
+        Updated (refs, merge_base) tuple.
+    """
+    if all:
+        if refs and refs != REFS_VALUE_ALL:
+            raise typer.BadParameter(
+                "The --all option overrides the refs argument. "
+                "Please remove the refs argument if you want to review all codebase."
+            )
+        refs = REFS_VALUE_ALL
+        merge_base = False
+    return refs, merge_base
+
+
 @app_no_subcommand.command(name="review", help="Perform code review")
 @app.command(name="review", help="Perform a code review of the target codebase changes.")
 @app.command(name="run", hidden=True)
@@ -109,16 +128,9 @@ def cmd_review(
         """)
     ),
     out: str = arg_out(),
-    all: bool = typer.Option(default=False, help="Review all codebase"),
+    all: bool = arg_all(),
 ):
-    if all:
-        if refs and refs != REFS_VALUE_ALL:
-            raise typer.BadParameter(
-                "The --all option overrides the refs argument. "
-                "Please remove the refs argument if you want to review all codebase."
-            )
-        refs = REFS_VALUE_ALL
-        merge_base = False
+    refs, merge_base = _consider_arg_all(all, refs, merge_base)
     _what, _against = args_to_target(refs, what, against)
     pr = pr or os.getenv("PR_NUMBER_FROM_WORKFLOW_DISPATCH")
     with get_repo_context(url, _what) as (repo, out_folder):
@@ -150,7 +162,6 @@ def cmd_review(
 
 @app.command(name="ask", help="Answer questions about the target codebase changes.")
 @app.command(name="answer", hidden=True)
-@app.command(name="talk", hidden=True)
 def cmd_answer(
     question: str = typer.Argument(help="Question to ask about the codebase changes"),
     refs: str = arg_refs(),
@@ -171,8 +182,15 @@ def cmd_answer(
     aux_files: list[str] = typer.Option(
         default=None,
         help="Auxiliary files that might be helpful"
-    )
+    ),
+    save_to: str = typer.Option(
+        help="Write the answer to the target file",
+        default=None,
+        show_default=False
+    ),
+    all: bool = arg_all(),
 ):
+    refs, merge_base = _consider_arg_all(all, refs, merge_base)
     _what, _against = args_to_target(refs, what, against)
     pr = pr or os.getenv("PR_NUMBER_FROM_WORKFLOW_DISPATCH")
     if str(question).startswith("tpl:"):
@@ -194,6 +212,11 @@ def cmd_answer(
     if post_to == 'linear':
         logging.info("Posting answer to Linear...")
         linear_comment(remove_html_comments(out))
+    if save_to:
+        with open(save_to, "w", encoding="utf-8") as f:
+            f.write(out)
+        logging.info(f"Answer saved to {mc.utils.file_link(save_to)}")
+
     return out
 
 
@@ -234,6 +257,9 @@ def files(
     try:
         patch_set = get_diff(repo=repo, what=_what, against=_against, use_merge_base=merge_base)
         patch_set = filter_diff(patch_set, filters)
+        cfg = ProjectConfig.load_for_repo(repo)
+        if cfg.exclude_files:
+            patch_set = filter_diff(patch_set, cfg.exclude_files, exclude=True)
         print(
             f"Changed files: "
             f"{mc.ui.green(_what or 'INDEX')} vs "
